@@ -49,12 +49,16 @@
 
 import csv
 import os
-
-import numpy as np
-import librosa
-from mirdata import annotations, core, download_utils, io, jams_utils
 from typing import BinaryIO, Optional, TextIO, Tuple
 
+from deprecated.sphinx import deprecated
+import librosa
+import numpy as np
+from smart_open import open
+
+from mirdata import annotations, core, download_utils, io, jams_utils
+
+
 BIBTEX = """
 @dataset{rong_gong_2018_1323561,
   author       = {Rong Gong and
@@ -77,6 +81,12 @@ BIBTEX = """
 }
 """
 
+INDEXES = {
+    "default": "7.0",
+    "test": "7.0",
+    "7.0": core.Index(filename="compmusic_jingju_acappella_index_7.0.json"),
+}
+
 REMOTES = {
     "annotation_txt": download_utils.RemoteFileMetadata(
         filename="annotation_txt.zip",
@@ -105,7 +115,8 @@ REMOTES = {
 }
 
 LICENSE_INFO = (
-    "audio files ending with upf or lon: Creative Commons Attribution Non-Commercial 4.0 International, "
+    "audio files ending with upf or lon: Creative Commons Attribution Non-Commercial 4.0"
+    " International, "
     + "audio files ending with qm: http://isophonics.org/SingingVoiceDataset"
 )
 
@@ -202,8 +213,12 @@ class Track(core.Track):
         """
         return jams_utils.jams_converter(
             audio_path=self.audio_path,
-            lyrics_data=[(self.phrase, "phrases"), (self.phrase_char, "phrases_char")],
-            event_data=[(self.phoneme, "phoneme"), (self.syllable, "syllable")],
+            lyrics_data=[
+                (self.phrase, "phrases"),
+                (self.phrase_char, "phrases_char"),
+                (self.phoneme, "phoneme"),
+                (self.syllable, "syllable"),
+            ],
             metadata={
                 "work": self.work,
                 "details": self.details,
@@ -226,14 +241,14 @@ def load_audio(fhandle: BinaryIO) -> Tuple[np.ndarray, float]:
 
 
 @io.coerce_to_string_io
-def load_phonemes(fhandle: TextIO) -> annotations.EventData:
+def load_phonemes(fhandle: TextIO) -> annotations.LyricData:
     """Load phonemes
 
     Args:
         fhandle (str or file-like): path or file-like object pointing to a phoneme annotation file
 
     Returns:
-        EventData: phoneme annotation
+        LyricData: phoneme annotation
 
     """
 
@@ -247,7 +262,9 @@ def load_phonemes(fhandle: TextIO) -> annotations.EventData:
         end_times.append(float(line[1]))
         events.append(str(line[2] if line[2] != "sil" else ""))
 
-    return annotations.EventData(np.array([start_times, end_times]).T, events)
+    return annotations.LyricData(
+        np.array([start_times, end_times]).T, "s", events, "pronunciations_open"
+    )
 
 
 @io.coerce_to_string_io
@@ -272,20 +289,19 @@ def load_phrases(fhandle: TextIO) -> annotations.LyricData:
         lyrics.append(line[2] if line[2] != "sil" else "")
 
     return annotations.LyricData(
-        np.array([start_times, end_times]).T,
-        lyrics,
+        np.array([start_times, end_times]).T, "s", lyrics, "words"
     )
 
 
 @io.coerce_to_string_io
-def load_syllable(fhandle: TextIO) -> annotations.EventData:
+def load_syllable(fhandle: TextIO) -> annotations.LyricData:
     """Load syllable
 
     Args:
         fhandle (str or file-like): path or file-like object pointing to a syllable annotation file
 
     Returns:
-        EventData: syllable annotation
+        LyricData: syllable annotation
 
     """
 
@@ -299,7 +315,9 @@ def load_syllable(fhandle: TextIO) -> annotations.EventData:
         end_times.append(float(line[1]))
         events.append(line[2] if line[2] != "sil" else "")
 
-    return annotations.EventData(np.array([start_times, end_times]).T, events)
+    return annotations.LyricData(
+        np.array([start_times, end_times]).T, "s", events, "syllable_open"
+    )
 
 
 @core.docstring_inherit(core.Dataset)
@@ -308,12 +326,14 @@ class Dataset(core.Dataset):
     The compmusic_jingju_acappella dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="compmusic_jingju_acappella",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             license_info=LICENSE_INFO,
         )
@@ -324,40 +344,47 @@ class Dataset(core.Dataset):
             self.data_home,
             "catalogue - laosheng.csv",
         )
-        metadata_path_dan = os.path.join(
-            self.data_home,
-            "catalogue - dan.csv",
-        )
-        if not os.path.exists(metadata_path_laosheng):
+        # metadata_path_dan = os.path.join(
+        #     self.data_home,
+        #     "catalogue - dan.csv",
+        # )
+
+        metadata = {}
+        try:
+            with open(metadata_path_laosheng, "r") as fhandle:
+                reader = csv.reader(fhandle, delimiter=",")
+                next(reader)
+                for line in reader:
+                    work = line[1] if line[1] else None
+                    details = line[3] if line[3] else None
+                    metadata[line[0]] = {"work": work, "details": details}
+
+                data_home = os.path.dirname(metadata_path_laosheng)
+                metadata["data_home"] = data_home
+        except FileNotFoundError:
             raise FileNotFoundError(
                 "laosheng metadata not found. Did you run .download()?"
             )
 
-        if not os.path.exists(metadata_path_dan):
-            raise FileNotFoundError("dan metadata not found. Did you run .download()?")
-
-        metadata = {}
-        with open(metadata_path_laosheng, "r") as fhandle:
-            reader = csv.reader(fhandle, delimiter=",")
-            next(reader)
-            for line in reader:
-                work = line[1] if line[1] else None
-                details = line[3] if line[3] else None
-                metadata[line[0]] = {"work": work, "details": details}
-
-            data_home = os.path.dirname(metadata_path_laosheng)
-            metadata["data_home"] = data_home
-
         return metadata
 
-    @core.copy_docs(load_phonemes)
+    @deprecated(
+        reason="Use mirdata.datasets.jingju_acapella.load_phonemes",
+        version="0.3.4",
+    )
     def load_phonemes(self, *args, **kwargs):
         return load_phonemes(*args, **kwargs)
 
-    @core.copy_docs(load_phrases)
+    @deprecated(
+        reason="Use mirdata.datasets.jingju_acapella.load_phrases",
+        version="0.3.4",
+    )
     def load_phrases(self, *args, **kwargs):
         return load_phrases(*args, **kwargs)
 
-    @core.copy_docs(load_syllable)
+    @deprecated(
+        reason="Use mirdata.datasets.jingju_acapella.load_syllable",
+        version="0.3.4",
+    )
     def load_syllable(self, *args, **kwargs):
         return load_syllable(*args, **kwargs)
