@@ -35,9 +35,13 @@ import json
 import os
 from typing import TextIO
 
+from deprecated.sphinx import deprecated
 import numpy as np
+from smart_open import open
+
 from mirdata import annotations, core, download_utils, io, jams_utils
 
+
 BIBTEX = """
 @software{sertan_senturk_2016_58413,
   author       = {Sertan Şentürk and
@@ -53,6 +57,12 @@ BIBTEX = """
 }
 """
 
+INDEXES = {
+    "default": "dlfm2016",
+    "test": "dlfm2016",
+    "dlfm2016": core.Index(filename="compmusic_otmm_makam_index_dlfm2016.json"),
+}
+
 REMOTES = {
     "all": download_utils.RemoteFileMetadata(
         filename="otmm_makam_recognition_dataset-dlfm2016.zip",
@@ -162,9 +172,10 @@ def load_pitch(fhandle: TextIO) -> annotations.F0Data:
     reader = csv.reader(fhandle, delimiter=",")
     freqs = np.array([float(line[0]) for line in reader])
     times = np.array(np.arange(len(freqs)) * time_step)
-    confidence = np.array((freqs > 0.0).astype(float))
+    voicing = (freqs > 0.0).astype(float)
+    freqs = np.abs(freqs)
 
-    return annotations.F0Data(times, freqs, confidence)
+    return annotations.F0Data(times, "s", freqs, "hz", voicing, "binary")
 
 
 @io.coerce_to_string_io
@@ -188,12 +199,14 @@ class Dataset(core.Dataset):
     The compmusic_otmm_makam dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="compmusic_otmm_makam",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             license_info=LICENSE_INFO,
         )
@@ -205,30 +218,37 @@ class Dataset(core.Dataset):
             "MTG-otmm_makam_recognition_dataset-f14c0d0",
             "annotations.json",
         )
-        if not os.path.exists(metadata_path):
-            raise FileNotFoundError("Metadata not found. Did you run .download()?")
 
         metadata = {}
-        with open(metadata_path) as f:
-            meta = json.load(f)
-            for i in meta:
-                index = i["mbid"].split("/")[-1]
-                metadata[index] = {
-                    "makam": i["makam"],
-                    "tonic": i["tonic"],
-                    "mbid": index,
-                }
+        try:
+            with open(metadata_path) as f:
+                meta = json.load(f)
+                for i in meta:
+                    index = i["mbid"].split("/")[-1]
+                    metadata[index] = {
+                        "makam": i["makam"],
+                        "tonic": i["tonic"],
+                        "mbid": index,
+                    }
+        except FileNotFoundError:
+            raise FileNotFoundError("Metadata not found. Did you run .download()?")
 
-            temp = metadata_path.split("/")[-2]
-            data_home = metadata_path.split(temp)[0]
-            metadata["data_home"] = data_home
+        temp = metadata_path.split("/")[-2]
+        data_home = metadata_path.split(temp)[0]
+        metadata["data_home"] = data_home
 
         return metadata
 
-    @core.copy_docs(load_pitch)
+    @deprecated(
+        reason="Use mirdata.datasets.compmusic_otmm_makam.load_pitch",
+        version="0.3.4",
+    )
     def load_pitch(self, *args, **kwargs):
         return load_pitch(*args, **kwargs)
 
-    @core.copy_docs(load_mb_tags)
+    @deprecated(
+        reason="Use mirdata.datasets.compmusic_otmm_makam.load_mb_tags",
+        version="0.3.4",
+    )
     def load_mb_tags(self, *args, **kwargs):
         return load_mb_tags(*args, **kwargs)
