@@ -53,15 +53,15 @@
 """
 import logging
 import os
+from typing import BinaryIO, Optional, TextIO, Tuple, Dict, List
+
+from deprecated.sphinx import deprecated
 import jams
 import librosa
 import numpy as np
-from typing import BinaryIO, Optional, TextIO, Tuple
+from smart_open import open
 
-from mirdata import download_utils
-from mirdata import core
-from mirdata import annotations
-from mirdata import io
+from mirdata import annotations, core, download_utils, io
 
 
 BIBTEX = """@inproceedings{xi2018guitarset,
@@ -71,6 +71,12 @@ booktitle={International Society of Music Information Retrieval (ISMIR)},
 year={2018}
 }"""
 
+INDEXES = {
+    "default": "1.1.0",
+    "test": "1.1.0",
+    "1.1.0": core.Index(filename="guitarset_index_1.1.0.json"),
+}
+
 REMOTES = {
     "annotations": download_utils.RemoteFileMetadata(
         filename="annotation.zip",
@@ -111,6 +117,7 @@ _STYLE_DICT = {
     "Funk": "Funk",
 }
 _GUITAR_STRINGS = ["E", "A", "D", "G", "B", "e"]
+CONTOUR_HOP = 256.0 / 44100
 
 LICENSE_INFO = "MIT License."
 
@@ -149,6 +156,7 @@ class Track(core.Track):
             - 'G': F0Data(...)
             - 'B': F0Data(...)
             - 'e': F0Data(...)
+        multif0 (MultiF0Data): all pitch contour data as one multif0 annotation
         notes (dict):
             Notes per string
             - 'E': NoteData(...)
@@ -157,6 +165,7 @@ class Track(core.Track):
             - 'G': NoteData(...)
             - 'B': NoteData(...)
             - 'e': NoteData(...)
+        notes_all (NoteData): all note data as one note annotation
 
     """
 
@@ -199,7 +208,7 @@ class Track(core.Track):
             logging.info(
                 "Chord annotations for solo excerpts are the same with the comp excerpt."
             )
-        return load_chords(self.jams_path, leadsheet_version=True)
+        return load_chords(self.jams_path, True)
 
     @core.cached_property
     def inferred_chords(self):
@@ -207,14 +216,14 @@ class Track(core.Track):
             logging.info(
                 "Chord annotations for solo excerpts are the same as the comp excerpt."
             )
-        return load_chords(self.jams_path, leadsheet_version=False)
+        return load_chords(self.jams_path, False)
 
     @core.cached_property
     def key_mode(self) -> Optional[annotations.KeyData]:
         return load_key_mode(self.jams_path)
 
     @core.cached_property
-    def pitch_contours(self):
+    def pitch_contours(self) -> Dict[str, annotations.F0Data]:
         contours = {}
         # iterate over 6 strings
         for i in range(6):
@@ -222,13 +231,43 @@ class Track(core.Track):
         return contours
 
     @core.cached_property
-    def notes(self):
+    def multif0(self) -> annotations.MultiF0Data:
+        contours: List[annotations.F0Data] = list(self.pitch_contours.values())
+        max_times = np.argmax(
+            [
+                0 if contour_data is None else len(contour_data.times)
+                for contour_data in contours
+            ],
+        )  # type: ignore
+        times = contours[max_times].times  # type: ignore
+        frequency_list: List[list] = [[] for _ in times]
+        for contour in contours:
+            if contour is None:
+                continue
+
+            for i, f in enumerate(contour.frequencies):
+                if f > 0:
+                    frequency_list[i].append(f)
+        return annotations.MultiF0Data(times, "s", frequency_list, "hz")
+
+    @core.cached_property
+    def notes(self) -> Dict[str, annotations.NoteData]:
         notes = {}
         # iterate over 6 strings
         for i in range(6):
             notes[_GUITAR_STRINGS[i]] = load_notes(self.jams_path, i)
         return notes
 
+    @core.cached_property
+    def notes_all(self) -> Optional[annotations.NoteData]:
+        all_note_data = None
+        for note_data in self.notes.values():
+            if all_note_data is None:
+                all_note_data = note_data
+            else:
+                all_note_data += note_data
+        return all_note_data
+
     @property
     def audio_mic(self) -> Optional[Tuple[np.ndarray, float]]:
         """The track's audio
@@ -319,7 +358,8 @@ def load_beats(fhandle: TextIO) -> annotations.BeatData:
     """Load a Guitarset beats annotation.
 
     Args:
-        fhandle (str or file-like): File-like object or path of the jams annotation file
+        fhandle (str or file-like): File-like object or path
+            of the jams annotation file
 
     Returns:
         BeatData: Beat data
@@ -328,14 +368,15 @@ def load_beats(fhandle: TextIO) -> annotations.BeatData:
     anno = jam.search(namespace="beat_position")[0]
     times, values = anno.to_event_values()
     positions = [int(v["position"]) for v in values]
-    return annotations.BeatData(times, np.array(positions))
+    return annotations.BeatData(times, "s", np.array(positions), "bar_index")
 
 
-def load_chords(jams_path, leadsheet_version=True):
+# no decorator because of https://github.com/mir-dataset-loaders/mirdata/issues/503
+def load_chords(jams_path, leadsheet_version):
     """Load a guitarset chord annotation.
 
     Args:
-        jams_path (str): Path of the jams annotation file
+        jams_path (str): path to the jams annotation file
         leadsheet_version (Bool):
             Whether or not to load the leadsheet version of the chord annotation
             If False, load the infered version.
@@ -344,15 +385,18 @@ def load_chords(jams_path, leadsheet_version=True):
         ChordData: Chord data
 
     """
-    if not os.path.exists(jams_path):
-        raise IOError("jams_path {} does not exist".format(jams_path))
-    jam = jams.load(jams_path)
+    try:
+        with open(jams_path, "r") as fhandle:
+            jam = jams.load(fhandle)
+    except FileNotFoundError:
+        raise FileNotFoundError("jams_path {} does not exist".format(jams_path))
+
     if leadsheet_version:
         anno = jam.search(namespace="chord")[0]
     else:
         anno = jam.search(namespace="chord")[1]
     intervals, values = anno.to_interval_values()
-    return annotations.ChordData(intervals, values)
+    return annotations.ChordData(intervals, "s", values, "jams")
 
 
 @io.coerce_to_string_io
@@ -369,14 +413,46 @@ def load_key_mode(fhandle: TextIO) -> annotations.KeyData:
     jam = jams.load(fhandle)
     anno = jam.search(namespace="key_mode")[0]
     intervals, values = anno.to_interval_values()
-    return annotations.KeyData(intervals, values)
+    return annotations.KeyData(intervals, "s", values, "key_mode")
 
 
+def _fill_pitch_contour(times, freqs, voicing, max_time, contour_hop, duration=None):
+    """Fill a pitch contour with missing time stamps (during unpitched frames)
+
+    Args:
+        times (np.array): array of time stamps in seconds
+        freqs (np.array): array of pitch values in Hz
+        voicing (np.array): array of voicings
+        max_time (float): maximum time stamp
+        contour_hop (float): hop size in seconds
+        duration (float, optional): Total duration. Defaults to None.
+
+    Returns:
+        tuple: filled_times, filled_frequencies, filled_voicing
+    """
+    if duration is not None and max_time > duration:
+        max_time = duration
+    n_stamps = int(np.floor((max_time / contour_hop)))
+    filled_times = np.arange(n_stamps) * contour_hop
+    filled_freqs = np.zeros((len(filled_times),))
+    filled_voicing = np.zeros((len(filled_times),))
+
+    for time, freq, voc in zip(times, freqs, voicing):
+        t_idx = int(np.round(time / contour_hop))
+        if time > max_time or t_idx >= n_stamps:
+            continue
+        filled_freqs[t_idx] = freq
+        filled_voicing[t_idx] = voc
+
+    return filled_times, filled_freqs, filled_voicing
+
+
+# no decorator because of https://github.com/mir-dataset-loaders/mirdata/issues/503
 def load_pitch_contour(jams_path, string_num):
     """Load a guitarset pitch contour annotation for a given string
 
     Args:
-        jams_path (str): Path of the jams annotation file
+        jams_path (str): path to the jams annotation file
         string_num (int), in range(6): Which string to load.
             0 is the Low E string, 5 is the high e string.
 
@@ -384,23 +460,36 @@ def load_pitch_contour(jams_path, string_num):
         F0Data: Pitch contour data for the given string
 
     """
-    if not os.path.exists(jams_path):
-        raise IOError("jams_path {} does not exist".format(jams_path))
-    jam = jams.load(jams_path)
+    try:
+        with open(jams_path, "r") as fhandle:
+            jam = jams.load(fhandle)
+    except FileNotFoundError:
+        raise FileNotFoundError("jams_path {} does not exist".format(jams_path))
+
     anno_arr = jam.search(namespace="pitch_contour")
     anno = anno_arr.search(data_source=str(string_num))[0]
     times, values = anno.to_event_values()
     if len(times) == 0:
         return None
-    frequencies = [v["frequency"] for v in values]
-    return annotations.F0Data(times, np.array(frequencies))
+    frequencies = np.array([v["frequency"] for v in values])
+    voicing = np.array([float(v["voiced"]) for v in values])
+    voicing[frequencies == 0] = 0
+
+    filled_times, filled_freqs, filled_voicing = _fill_pitch_contour(
+        times, frequencies, voicing, np.max(times), CONTOUR_HOP
+    )
+
+    return annotations.F0Data(
+        filled_times, "s", filled_freqs, "hz", filled_voicing, "binary"
+    )
 
 
+# no decorator because of https://github.com/mir-dataset-loaders/mirdata/issues/503
 def load_notes(jams_path, string_num):
     """Load a guitarset note annotation for a given string
 
     Args:
-        jams_path (str): Path of the jams annotation file
+        jams_path (str): path to the jams annotation file
         string_num (int), in range(6): Which string to load.
             0 is the Low E string, 5 is the high e string.
 
@@ -408,15 +497,18 @@ def load_notes(jams_path, string_num):
         NoteData: Note data for the given string
 
     """
-    if not os.path.exists(jams_path):
-        raise IOError("jams_path {} does not exist".format(jams_path))
-    jam = jams.load(jams_path)
+    try:
+        with open(jams_path) as fhandle:
+            jam = jams.load(fhandle)
+    except FileNotFoundError:
+        raise FileNotFoundError("jams_path {} does not exist".format(jams_path))
+
     anno_arr = jam.search(namespace="note_midi")
     anno = anno_arr.search(data_source=str(string_num))[0]
     intervals, values = anno.to_interval_values()
     if len(values) == 0:
         return None
-    return annotations.NoteData(intervals, np.array(values))
+    return annotations.NoteData(intervals, "s", np.array(values), "midi")
 
 
 @core.docstring_inherit(core.Dataset)
@@ -425,40 +517,63 @@ class Dataset(core.Dataset):
     The guitarset dataset
     """
 
-    def __init__(self, data_home=None):
+    def __init__(self, data_home=None, version="default"):
         super().__init__(
             data_home,
+            version,
             name="guitarset",
             track_class=Track,
             bibtex=BIBTEX,
+            indexes=INDEXES,
             remotes=REMOTES,
             license_info=LICENSE_INFO,
         )
 
-    @core.copy_docs(load_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_audio",
+        version="0.3.4",
+    )
     def load_audio(self, *args, **kwargs):
         return load_audio(*args, **kwargs)
 
-    @core.copy_docs(load_multitrack_audio)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_multitrack_audio",
+        version="0.3.4",
+    )
     def load_multitrack_audio(self, *args, **kwargs):
         return load_multitrack_audio(*args, **kwargs)
 
-    @core.copy_docs(load_beats)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_beats",
+        version="0.3.4",
+    )
     def load_beats(self, *args, **kwargs):
         return load_beats(*args, **kwargs)
 
-    @core.copy_docs(load_chords)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_chords",
+        version="0.3.4",
+    )
     def load_chords(self, *args, **kwargs):
         return load_chords(*args, **kwargs)
 
-    @core.copy_docs(load_key_mode)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_key_mode",
+        version="0.3.4",
+    )
     def load_key_mode(self, *args, **kwargs):
         return load_key_mode(*args, **kwargs)
 
-    @core.copy_docs(load_pitch_contour)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_pitch_contour",
+        version="0.3.4",
+    )
     def load_pitch_contour(self, *args, **kwargs):
         return load_pitch_contour(*args, **kwargs)
 
-    @core.copy_docs(load_notes)
+    @deprecated(
+        reason="Use mirdata.datasets.guitarset.load_notes",
+        version="0.3.4",
+    )
     def load_notes(self, *args, **kwargs):
         return load_notes(*args, **kwargs)
